"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const tf = __importStar(require("@tensorflow/tfjs-node-gpu"));
function createDataset(loader, labelMap) {
    return __awaiter(this, void 0, void 0, function* () {
        const inputs = [];
        const len = yield loader.len();
        const onehotLen = labelMap.length;
        for (let i = 0; i < len; i++) {
            const sample = yield loader.getItem(i);
            inputs.push(tf.tidy(() => {
                return {
                    xs: tf.tidy(() => sample.data),
                    ys: tf.tidy(() => tf.oneHot(tf.scalar(sample.label, 'int32'), onehotLen))
                };
            }));
        }
        return tf.data.array(inputs);
    });
}
/**
 *
 * @param data Pipcook uniform sample data
 * @param model Pipcook model
 * @param args args: specify batch size, total batches to iterate
 */
const evlauate = (dataset, uniModel) => __awaiter(void 0, void 0, void 0, function* () {
    const batchSize = 16;
    const { testLoader, metadata } = dataset;
    if (!testLoader) {
        return { pass: true };
    }
    const count = yield testLoader.len();
    const batches = Math.floor(count / batchSize);
    const testDataset = yield createDataset(testLoader, metadata.labelMap);
    console.info('created test dataset', testDataset);
    const ds = testDataset.repeat().batch(batchSize);
    const model = uniModel.model;
    let result = yield model.evaluateDataset(ds, { batches });
    if (!Array.isArray(result)) {
        result = [result];
    }
    // update metrics
    let metrics = ['loss'];
    if (model.metrics) {
        metrics = [...metrics, ...uniModel.metrics];
    }
    const evalRes = { pass: true };
    metrics.forEach((metric, idx) => {
        evalRes[metric] = result[idx].dataSync();
    });
    return evalRes;
});
exports.default = evlauate;
//# sourceMappingURL=index.js.map